==> kubernetes-model-resource-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingListFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSchedulingListFluent<A extends PodSchedulingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,PodScheduling item);
  public A setToItems(Integer index,PodScheduling item);
  public A addToItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.PodScheduling... items);
  public A addAllToItems(Collection<PodScheduling> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.PodScheduling... items);
  public A removeAllFromItems(Collection<PodScheduling> items);
  public A removeMatchingFromItems(Predicate<PodSchedulingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodScheduling> getItems();
  public List<PodScheduling> buildItems();
  public PodScheduling buildItem(Integer index);
  public PodScheduling buildFirstItem();
  public PodScheduling buildLastItem();
  public PodScheduling buildMatchingItem(Predicate<PodSchedulingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PodSchedulingBuilder> predicate);
  public A withItems(List<PodScheduling> items);
  public A withItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.PodScheduling... items);
  public Boolean hasItems();
  public PodSchedulingListFluent.ItemsNested<A> addNewItem();
  public PodSchedulingListFluent.ItemsNested<A> addNewItemLike(PodScheduling item);
  public PodSchedulingListFluent.ItemsNested<A> setNewItemLike(Integer index,PodScheduling item);
  public PodSchedulingListFluent.ItemsNested<A> editItem(Integer index);
  public PodSchedulingListFluent.ItemsNested<A> editFirstItem();
  public PodSchedulingListFluent.ItemsNested<A> editLastItem();
  public PodSchedulingListFluent.ItemsNested<A> editMatchingItem(Predicate<PodSchedulingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,PodSchedulingFluent<PodSchedulingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-resource-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingListFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSchedulingListFluent<A extends PodSchedulingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,PodScheduling item);
  public A setToItems(int index,PodScheduling item);
  public A addToItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.PodScheduling... items);
  public A addAllToItems(Collection<PodScheduling> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.PodScheduling... items);
  public A removeAllFromItems(Collection<PodScheduling> items);
  public A removeMatchingFromItems(Predicate<PodSchedulingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodScheduling> getItems();
  public List<PodScheduling> buildItems();
  public PodScheduling buildItem(int index);
  public PodScheduling buildFirstItem();
  public PodScheduling buildLastItem();
  public PodScheduling buildMatchingItem(Predicate<PodSchedulingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PodSchedulingBuilder> predicate);
  public A withItems(List<PodScheduling> items);
  public A withItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.PodScheduling... items);
  public Boolean hasItems();
  public PodSchedulingListFluent.ItemsNested<A> addNewItem();
  public PodSchedulingListFluent.ItemsNested<A> addNewItemLike(PodScheduling item);
  public PodSchedulingListFluent.ItemsNested<A> setNewItemLike(int index,PodScheduling item);
  public PodSchedulingListFluent.ItemsNested<A> editItem(int index);
  public PodSchedulingListFluent.ItemsNested<A> editFirstItem();
  public PodSchedulingListFluent.ItemsNested<A> editLastItem();
  public PodSchedulingListFluent.ItemsNested<A> editMatchingItem(Predicate<PodSchedulingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,PodSchedulingFluent<PodSchedulingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
